# flake8-numba

[WORK IN PROGRESS, ALPHA VERSION]

Improve your Python development experience with flake8-numba. This plugin integrates with Flake8 to provide
comprehensive code analysis for projects that make use of numba. When working with numba, many errors are not
discovered until the code is run. However, many of these issues can be perfectly caught by performing some basic
syntactical analysis. This tool helps you catch potential errors and enhance code quality effortlessly.

## Installation

Make sure that you have `flake8` installed. Then:

```
pip install flake8-numba
```

After it calling `flake8` will include all rules defined by this plugin.

## Rules

Available rules can be read in [RULES.md](RULES.md)
